/* Asteroids3D - a first person game of blowing up asteroids
 * Copyright (C) 2000 Stuart Mark Pomerantz
 *
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  Stuart Pomerantz
 *  3935 Stonecliffe drive
 *  Monroeville, PA 15146
 *  stuart@pitt.edu
 */
 
#include "asteroids3D.h"

void calculate_frame(void) {
	extern float dt ;
	extern unsigned long ticks ;
	extern sem_t run_yield ;
	extern int game_end_flag ;
	while( 1 ) {

		usleep(dt*1000000) ;

		if( paused() ) /* must continue to compute dt even if paused. */
			continue ;

		if( game_end_flag == 1 )
			break ;

		sem_wait( &run_yield ) ;
		
		capture_passive_mouse_input() ;		
		apply_thrust(1) ; /* keyboard & mouse motion */		
		process_motion(1) ; /* ship motion */		
		process_asteroid_motion(1) ;	/* ...and asteroid motion. Comment this out to browse the data set */
		process_deleted_ast() ;
		process_torpedo_motion(1) ;
		process_torpedo_trails() ;
		process_explosion(1) ;		
		process_dust() ;
		process_shield() ;
		process_sound() ;

		ticks += 1 ;

		sem_post( &run_yield ) ;
	}
	
	pthread_exit(NULL) ;
}


void capture_passive_mouse_input(void) {
	extern int  mouse_roty_flag, mouse_rotx_flag ;
	extern float mouse_xprop, mouse_yprop ;

	if( paused() ) /* must continue to compute dt even if paused. HACK FIXME? */
		return ;

	/* capture passive mouse changes */

	if( mouse_roty_flag == 1)
		turn_abouty(MAX_DPS_INPUT*mouse_yprop) ;

	if( mouse_rotx_flag == 1 )
		turn_aboutx(MAX_DPS_INPUT*mouse_xprop) ;

	return ;
}
